"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitlicensekeyscreateproperties import (
    BenefitLicenseKeysCreateProperties,
    BenefitLicenseKeysCreatePropertiesTypedDict,
)
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from polar_sdk.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class BenefitLicenseKeysCreateTypedDict(TypedDict):
    description: str
    r"""The description of the benefit. Will be displayed on products having this benefit."""
    properties: BenefitLicenseKeysCreatePropertiesTypedDict
    type: Literal["license_keys"]
    organization_id: NotRequired[Nullable[str]]
    r"""The ID of the organization owning the benefit. **Required unless you use an organization token.**"""


class BenefitLicenseKeysCreate(BaseModel):
    description: str
    r"""The description of the benefit. Will be displayed on products having this benefit."""

    properties: BenefitLicenseKeysCreateProperties

    TYPE: Annotated[
        Annotated[
            Literal["license_keys"], AfterValidator(validate_const("license_keys"))
        ],
        pydantic.Field(alias="type"),
    ] = "license_keys"

    organization_id: OptionalNullable[str] = UNSET
    r"""The ID of the organization owning the benefit. **Required unless you use an organization token.**"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["organization_id"]
        nullable_fields = ["organization_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .licensekeyupdate import LicenseKeyUpdate, LicenseKeyUpdateTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class LicenseKeysUpdateRequestTypedDict(TypedDict):
    id: str
    license_key_update: LicenseKeyUpdateTypedDict


class LicenseKeysUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    license_key_update: Annotated[
        LicenseKeyUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
